import asyncio
import logging

import mini.mini_sdk as MiniSdk
from mini.blockapi.block_setup import StartRunProgram
from mini.dns.dns_browser import WiFiDevice


async def test_get_device_by_name():
    result = await MiniSdk.get_device_by_name("00018", 10)
    print(f"test_get_device_by_name result:{result}")
    return result


async def test_connect(dev: WiFiDevice):
    await MiniSdk.connect(dev)


async def test_start_run_program():
    await StartRunProgram().execute()
    await asyncio.sleep(6)


async def shutdown():
    await asyncio.sleep(1)
    await MiniSdk.release()


MiniSdk.set_log_level(logging.INFO)

if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(shutdown())



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: codemao_stopcustomaction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()

DESCRIPTOR = _descriptor.FileDescriptor(
    name='codemao_stopcustomaction.proto',
    package='',
    syntax='proto3',
    serialized_options=b'\n\025com.ubtechinc.codemao',
    serialized_pb=b'\n\x1e\x63odemao_stopcustomaction.proto\"-\n\x17StopCustomActionRequest\x12\x12\n\nactionName\x18\x01 \x01(\t\"A\n\x18StopCustomActionResponse\x12\x11\n\tisSuccess\x18\x01 \x01(\x08\x12\x12\n\nresultCode\x18\x02 \x01(\x05\x42\x17\n\x15\x63om.ubtechinc.codemaob\x06proto3'
)

_STOPCUSTOMACTIONREQUEST = _descriptor.Descriptor(
    name='StopCustomActionRequest',
    full_name='StopCustomActionRequest',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='actionName', full_name='StopCustomActionRequest.actionName', index=0,
            number=1, type=9, cpp_type=9, label=1,
            has_default_value=False, default_value=b"".decode('utf-8'),
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=34,
    serialized_end=79,
)

_STOPCUSTOMACTIONRESPONSE = _descriptor.Descriptor(
    name='StopCustomActionResponse',
    full_name='StopCustomActionResponse',
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name='isSuccess', full_name='StopCustomActionResponse.isSuccess', index=0,
            number=1, type=8, cpp_type=7, label=1,
            has_default_value=False, default_value=False,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
        _descriptor.FieldDescriptor(
            name='resultCode', full_name='StopCustomActionResponse.resultCode', index=1,
            number=2, type=5, cpp_type=1, label=1,
            has_default_value=False, default_value=0,
            message_type=None, enum_type=None, containing_type=None,
            is_extension=False, extension_scope=None,
            serialized_options=None, file=DESCRIPTOR),
    ],
    extensions=[
    ],
    nested_types=[],
    enum_types=[
    ],
    serialized_options=None,
    is_extendable=False,
    syntax='proto3',
    extension_ranges=[],
    oneofs=[
    ],
    serialized_start=81,
    serialized_end=146,
)

DESCRIPTOR.message_types_by_name['StopCustomActionRequest'] = _STOPCUSTOMACTIONREQUEST
DESCRIPTOR.message_types_by_name['StopCustomActionResponse'] = _STOPCUSTOMACTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StopCustomActionRequest = _reflection.GeneratedProtocolMessageType('StopCustomActionRequest', (_message.Message,), {
    'DESCRIPTOR': _STOPCUSTOMACTIONREQUEST,
    '__module__': 'codemao_stopcustomaction_pb2'
    # @@protoc_insertion_point(class_scope:StopCustomActionRequest)
})
_sym_db.RegisterMessage(StopCustomActionRequest)

StopCustomActionResponse = _reflection.GeneratedProtocolMessageType('StopCustomActionResponse', (_message.Message,), {
    'DESCRIPTOR': _STOPCUSTOMACTIONRESPONSE,
    '__module__': 'codemao_stopcustomaction_pb2'
    # @@protoc_insertion_point(class_scope:StopCustomActionResponse)
})
_sym_db.RegisterMessage(StopCustomActionResponse)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



import asyncio

from mini.blockapi import errors
from mini.dns.dns_browser import WiFiDevice
from test.test_connect import test_connect, shutdown
from test.test_connect import test_get_device_by_name, test_start_run_program

from mini.blockapi.base_api import BlockApiResultType
from mini.blockapi.block_sound import PlayTTS, ControlTTSResponse, TTSControlType
from mini.blockapi.block_sound import PlayAudio, PlayAudioResponse
from mini.blockapi.block_sound import FetchAudioList, GetAudioListResponse, AudioType
from mini.blockapi.block_sound import StopAllAudio, StopAudioResponse
from mini.blockapi.block_sound import PlayOnlineMusic, MusicResponse


async def test_play_tts():
    block: PlayTTS = PlayTTS(text="你好， 我是悟空， 啦啦啦", control_type=TTSControlType.START)
    (resultType, response) = await block.execute()

    print(f'test_play_tts result: {response}')
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == BlockApiResultType.Success, 'test_play_tts timetout'
    assert response is not None and isinstance(response, ControlTTSResponse), 'test_play_tts result unavailable'
    assert response.isSuccess, 'test_play_tts failed'


async def test_play_audio():
    block: PlayAudio = PlayAudio(
        url=["http://yun.lnpan.com/music/download/ring/000/075/5653bae83917a892589b372782175dd8.amr"])
    (resultType, response) = await block.execute()

    print(f'test_play_audio result: {response}')
    print('resultCode = {0}, error = {1}'.format(response.resultCode, errors.get_speech_error_str(response.resultCode)))

    assert resultType == BlockApiResultType.Success, 'test_play_audio timetout'
    assert response is not None and isinstance(response, PlayAudioResponse), 'test_play_audio result unavailable'
    assert response.isSuccess, 'test_play_audio failed'


async def test_get_audio_list():
    block: FetchAudioList = FetchAudioList(audio_type=AudioType.INNER)
    (resultType, response) = await block.execute()

    print(f'test_get_audio_list result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_get_audio_list timetout'
    assert response is not None and isinstance(response, GetAudioListResponse), 'test_play_audio result unavailable'
    assert response.isSuccess, 'test_get_audio_list failed'


async def test_stop_audio():
    block: PlayTTS = PlayTTS(is_serial=False, text="你让我说，让我说，不要打断我，不要打断我，不要打断我")
    response = await block.execute()
    print(f'test_stop_audio.play_tts: {response}')
    await asyncio.sleep(2)
    block: StopAllAudio = StopAllAudio()
    (resultType, response) = await block.execute()

    print(f'test_stop_audio:{response}')

    assert resultType == BlockApiResultType.Success, 'test_stop_audio timetout'
    assert response is not None and isinstance(response, StopAudioResponse), 'test_stop_audio result unavailable'
    assert response.isSuccess, 'test_stop_audio failed'


async def test_play_online_music():
    block: PlayOnlineMusic = PlayOnlineMusic(name='我的世界')
    (resultType, response) = await block.execute()

    print(f'test_play_online_music result: {response}')

    assert resultType == BlockApiResultType.Success, 'test_play_online_music timetout'
    assert response is not None and isinstance(response, MusicResponse), 'test_play_online_music result unavailable'
    assert response.isSuccess, 'test_play_online_music failed'


if __name__ == '__main__':
    device: WiFiDevice = asyncio.get_event_loop().run_until_complete(test_get_device_by_name())
    if device:
        asyncio.get_event_loop().run_until_complete(test_connect(device))
        asyncio.get_event_loop().run_until_complete(test_start_run_program())
        asyncio.get_event_loop().run_until_complete(test_play_tts())
        asyncio.get_event_loop().run_until_complete(test_get_audio_list())
        asyncio.get_event_loop().run_until_complete(test_stop_audio())
        asyncio.get_event_loop().run_until_complete(test_play_online_music())
        asyncio.get_event_loop().run_until_complete(test_play_audio())
        asyncio.get_event_loop().run_until_complete(shutdown())



import setuptools

with open("README.md", "r") as f:
    long_desc = f.read()

setuptools.setup(
    name="alphamini",
    version="0.0.8",
    author='logic.peng',
    autho_email='logic.peng@ubtrobot.com',
    description="python sdk for ubtenic alphamini robot",
    long_description = long_desc,
    long_description_content_type="text/markdown",
    # url="",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    install_requires=[
        'websockets >= 8.1',
        'ifaddr >=0.1.6',
        'protobuf >= 3.12.2'
    ],
)
